@@ -50,16 +50,20 @@ pub trait DomainEvent:
     Serialize + DeserializeOwned + Clone + PartialEq + fmt::Debug + Sync + Send
 {
     /// A name specifying the event, used for event upcasting.
-    fn event_type(&self) -> &'static str;
+    fn event_type(&self) -> String;
     /// A version of the `event_type`, use for event upcasting.
-    fn event_version(&self) -> &'static str;
+    fn event_version(&self) -> String;
 }
 
-/// `EventEnvelope` is a data structure that encapsulates an event with along with it's pertinent
-/// information. All of the associated data will be transported and persisted together.
+/// `EventEnvelope` is a data structure that encapsulates an event with its pertinent
+/// information.
+/// All of the associated data will be transported and persisted together and will be available
+/// for queries.
 ///
 /// Within any system an event must be unique based on its' `aggregate_type`, `aggregate_id` and
 /// `sequence`.
+/// Thus an `EventEnvelope` provides a uniqueness value along with an event `payload` and
+/// `metadata`.
 #[derive(Debug)]
 pub struct EventEnvelope<A>
 where
@@ -69,12 +73,6 @@ where
     pub aggregate_id: String,
     /// The sequence number for an aggregate instance.
     pub sequence: usize,
-    /// The type of aggregate the event applies to.
-    pub aggregate_type: String,
-    /// The type of event.
-    pub event_type: String,
-    /// The event version.
-    pub event_version: String,
     /// The event payload with all business information.
     pub payload: A::Event,
     /// Additional metadata for use in auditing, logging or debugging purposes.
@@ -86,9 +84,6 @@ impl<A: Aggregate> Clone for EventEnvelope<A> {
         EventEnvelope {
             aggregate_id: self.aggregate_id.clone(),
             sequence: self.sequence,
-            aggregate_type: self.aggregate_type.clone(),
-            event_type: self.event_type.clone(),
-            event_version: self.event_version.clone(),
             payload: self.payload.clone(),
             metadata: self.metadata.clone(),
         }
@@ -96,39 +91,35 @@ impl<A: Aggregate> Clone for EventEnvelope<A> {
 }
 
 impl<A: Aggregate> EventEnvelope<A> {
-    /// A convenience function for packaging an event in an `EventEnvelope`, used for
-    /// testing `QueryProcessor`s.
-    pub fn new(
-        aggregate_id: String,
-        sequence: usize,
-        aggregate_type: String,
-        payload: A::Event,
-    ) -> Self {
+    /// A convenience function for packaging an event in an `EventEnvelope`.
+    /// This is provided to simplify testing `Query`s but should not be used with application logic.
+    #[deprecated(
+        since = "0.3.1",
+        note = "this convenience method will be removed in V0.4.0, EventEnvelope fields will remain public"
+    )]
+    pub fn new(aggregate_id: String, sequence: usize, payload: A::Event) -> Self {
         EventEnvelope {
             aggregate_id,
             sequence,
-            aggregate_type,
-            event_type: payload.event_type().to_string(),
-            event_version: payload.event_version().to_string(),
             payload,
             metadata: Default::default(),
         }
     }
     /// A convenience function for packaging an event in an `EventEnvelope`, used for
     /// testing `QueryProcessor`s. This version allows custom metadata to also be processed.
+    #[deprecated(
+        since = "0.3.1",
+        note = "this convenience method will be removed in V0.4.0, EventEnvelope fields will remain public"
+    )]
     pub fn new_with_metadata(
         aggregate_id: String,
         sequence: usize,
-        aggregate_type: String,
         payload: A::Event,
         metadata: HashMap<String, String>,
     ) -> Self {
         EventEnvelope {
             aggregate_id,
             sequence,
-            aggregate_type,
-            event_type: payload.event_type().to_string(),
-            event_version: payload.event_version().to_string(),
             payload,
             metadata,
         }
